Interface TimeAccessor.TimeProperty
- All Superinterfaces:
TimeAccessor, TimeAccessor.TimeMutator
- Enclosing interface:
TimeAccessor
Provides a time property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface TimeAccessor
TimeAccessor.TimeBuilder<B>, TimeAccessor.TimeMutator, TimeAccessor.TimeProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault floatThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the given time (setter) as ofTimeAccessor.TimeMutator.setTime(float, TimeUnit)and returns the very same value (getter).Methods inherited from interface TimeAccessor
getTimeMethods inherited from interface TimeAccessor.TimeMutator
setTime
-
Method Details
-
letTime
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given time (setter) as ofTimeAccessor.TimeMutator.setTime(float, TimeUnit)and returns the very same value (getter).- Parameters:
aTime- The time to set (viaTimeAccessor.TimeMutator.setTime(float, TimeUnit)).aTimeUnit- The time unit for the provided time (as ofTimeAccessor.TimeMutator.setTime(float, TimeUnit)).- Returns:
- Returns the time passed for it to be used in conclusive processing steps.
-