- All Implemented Interfaces:
Serializable,Comparable<TimeUnit>,Constable
The Enum TimeUnit.
- Author:
- steiner
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionlongReturns the divisor for the time unit to be converted to seconds.static longtoMilliseconds(TimeUnit aTimeUnit, long aTime) Converts a given time from the providedTimeUnitto milliseconds.floatConverts a given time from oneTimeUnitto this instance's time unit.static floattoTimeUnit(TimeUnit aFromTimeUnit, long aTime, TimeUnit aToTimeUnit) static TimeUnitReturns the enum constant of this class with the specified name.static TimeUnit[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
NANOSECOND
-
MILLISECOND
-
SECOND
-
MINUTE
-
HOUR
-
DAY
-
YEAR
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getMilliseconds
public long getMilliseconds()Returns the divisor for the time unit to be converted to seconds.- Returns:
- Divisor for the time unit to be converted to seconds.
-
toTime
-
toTimeUnit
-
toMilliseconds
-