Uses of Enum Class
org.refcodes.time.TimeUnit
-
Uses of TimeUnit in org.refcodes.time
Subclasses with type arguments of type TimeUnit in org.refcodes.timeMethods in org.refcodes.time that return TimeUnitModifier and TypeMethodDescriptionstatic TimeUnitReturns the enum constant of this class with the specified name.static TimeUnit[]TimeUnit.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.time with parameters of type TimeUnitModifier and TypeMethodDescriptionfloatRetrieves the time from the time property.default floatThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the given time (setter) as ofTimeAccessor.TimeMutator.setTime(float, TimeUnit)and returns the very same value (getter).voidSets the time for the time property.static longTimeUnit.toMilliseconds(TimeUnit aTimeUnit, long aTime) Converts a given time from the providedTimeUnitto milliseconds.floatConverts a given time from oneTimeUnitto this instance's time unit.static floatTimeUnit.toTimeUnit(TimeUnit aFromTimeUnit, long aTime, TimeUnit aToTimeUnit) Sets the time for the time property.