Package org.refcodes.time
package org.refcodes.time
-
ClassDescriptionThe
DateFormatcontainsDateandDateFormatrelated values useful for parsing from and formatting to dateStringinstances.TheDateFormatsrepresent sets ofDateFormatdefinitions.The Class DateUtility.Provides an accessor for a time property.TimeAccessor.TimeBuilder<B extends TimeAccessor.TimeBuilder<B>>Provides a builder method for a time property returning the builder for applying multiple build operations.Provides a mutator for a time property.Provides a time property.The Enum TimeUnit.