Enum DateFormat

    • Enum Constant Detail

      • NETSCAPE_COOKIE_DATE_FORMAT

        public static final DateFormat NETSCAPE_COOKIE_DATE_FORMAT
        Date format as used for cookies as of the Netscape cookie specification. See "https://de.wikipedia.org/wiki/HTTP-Cookie#Cookies_nach_Netscape-Spezifikation"
      • ALTERNATE_COOKIE_DATE_FORMAT

        public static final DateFormat ALTERNATE_COOKIE_DATE_FORMAT
        An alternate cookie date format also seen in documentations out there on the internet.
      • RFC_1123_DATE_TIME_ALIKE

        public static final DateFormat RFC_1123_DATE_TIME_ALIKE
        An alternate cookie date format also seen in documentations out there on the internet. Can format something like "Thu, 01-Jan-1970 00:00:10 GMT". Similar to the DateTimeFormatter.RFC_1123_DATE_TIME formatter.
      • MIN_DATE_FORMAT

        public static final DateFormat MIN_DATE_FORMAT
        Minimum sortable (first comes the year, last the day) date format, contains the date without the time.
      • NORM_DATE_FORMAT

        public static final DateFormat NORM_DATE_FORMAT
        Normal sortable (first comes the year, last the seconds) date format, contains the date and the time till a granularity of seconds. The character 'T' separates the date portion from the time portion of the date format in order to unambiguously parse a such formatted date String.
      • MAX_DATE_FORMAT

        public static final DateFormat MAX_DATE_FORMAT
        Maximum sortable (first comes the year, last the nanoseconds) date format, contains the date and the time till a granularity of milliseconds.The character 'T' separates the date portion from the time portion of the date format in order to unambiguously parse a such formatted date String.
      • ALTERNATE_DATE_FORMAT

        public static final DateFormat ALTERNATE_DATE_FORMAT
        Similar date format as NORM_DATE_FORMAT though not avoiding the space between the date and the time portion of the date format.
      • DE_DATE_FORMAT

        public static final DateFormat DE_DATE_FORMAT
        Date format as used in German speaking locations, first comes the day, last the year, all separated by a dot '.' character.
      • MIN_FILENAME_DATE_FORMAT

        public static final DateFormat MIN_FILENAME_DATE_FORMAT
        Date format usable for (parts of) a filename, e.g. for rotating log files or the such with a granularity of days.
      • NORM_FILENAME_DATE_FORMAT

        public static final DateFormat NORM_FILENAME_DATE_FORMAT
        Date format usable for (parts of) a filename, e.g. for rotating log files or the such with a granularity of seconds.
      • MAX_FILENAME_DATE_FORMAT

        public static final DateFormat MAX_FILENAME_DATE_FORMAT
        Date format usable for (parts of) a filename, e.g. for rotating log files or the such with a granularity of nanoseconds.
      • ISO8601_ZULU_TIME

        public static final DateFormat ISO8601_ZULU_TIME
        ISO8601, Z means "zero hour offset" also known as "Zulu time" (UTC).
      • ISO_ZONED_DATE_TIME

        public static final DateFormat ISO_ZONED_DATE_TIME
        The ISO-like date-time formatter that formats or parses a date-time with offset and zone, such as '2011-12-03T10:15:30+01:00[Europe/Paris]'.
      • ISO_OFFSET_DATE_TIME

        public static final DateFormat ISO_OFFSET_DATE_TIME
        The ISO date-time formatter that formats or parses a date-time with an offset, such as '2011-12-03T10:15:30+01:00'.
    • Method Detail

      • values

        public static DateFormat[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (DateFormat c : DateFormat.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static DateFormat valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • getFormatter

        public DateTimeFormatter getFormatter()
        Gets the formatter.
        Returns:
        the formatter