-
- All Superinterfaces:
TimeAccessor,TimeAccessor.TimeMutator
- Enclosing interface:
- TimeAccessor
public static interface TimeAccessor.TimeProperty extends TimeAccessor, TimeAccessor.TimeMutator
Provides a time property.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.time.TimeAccessor
TimeAccessor.TimeBuilder<B extends TimeAccessor.TimeBuilder<B>>, TimeAccessor.TimeMutator, TimeAccessor.TimeProperty
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default floatletTime(float aTime, TimeUnit aTimeUnit)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given time (setter) as ofTimeAccessor.TimeMutator.setTime(float, TimeUnit)and returns the very same value (getter).-
Methods inherited from interface org.refcodes.time.TimeAccessor
getTime
-
Methods inherited from interface org.refcodes.time.TimeAccessor.TimeMutator
setTime
-
-
-
-
Method Detail
-
letTime
default float letTime(float aTime, TimeUnit aTimeUnit)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given time (setter) as ofTimeAccessor.TimeMutator.setTime(float, TimeUnit)and returns the very same value (getter).- Parameters:
aTime- The time to set (viaTimeAccessor.TimeMutator.setTime(float, TimeUnit)).aTimeUnit- The time unit for the provided time (as ofTimeAccessor.TimeMutator.setTime(float, TimeUnit)).- Returns:
- Returns the time passed for it to be used in conclusive processing steps.
-
-