- All Implemented Interfaces:
Serializable,Comparable<TimeUnit>,java.lang.constant.Constable
public enum TimeUnit extends Enum<TimeUnit>
The Enum TimeUnit.
- Author:
- steiner
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants Enum Constant Description DAYHOURMILLISECONDMINUTENANOSECONDSECONDYEAR -
Method Summary
Modifier and Type Method Description longgetMilliseconds()Returns the divisor for the time unit to be converted to seconds.static longtoMilliseconds(TimeUnit aTimeUnit, long aTime)Converts a given time from the providedTimeUnitto milliseconds.floattoTime(TimeUnit aFromTimeUnit, long aFromTime)Converts a given time from oneTimeUnitto this instance's time unit.static floattoTimeUnit(TimeUnit aFromTimeUnit, long aTime, TimeUnit aToTimeUnit)static TimeUnitvalueOf(String name)Returns the enum constant of this type with the specified name.static TimeUnit[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
NANOSECOND
-
MILLISECOND
-
SECOND
-
MINUTE
-
HOUR
-
DAY
-
YEAR
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getMilliseconds
public long getMilliseconds()Returns the divisor for the time unit to be converted to seconds.- Returns:
- Divisor for the time unit to be converted to seconds.
-
toTime
Converts a given time from oneTimeUnitto this instance's time unit.- Parameters:
aFromTimeUnit- TheTimeUnitto convert from.aFromTime- The time to be converted.- Returns:
- The converted time as of the current instance's time unit.
-
toTimeUnit
-
toMilliseconds
Converts a given time from the providedTimeUnitto milliseconds.- Parameters:
aTimeUnit- TheTimeUnitto convert from.aTime- The time to be converted to milliseconds.- Returns:
- The converted time in milliseconds.
-