Uses of Enum
org.refcodes.time.DateFormat
-
Uses of DateFormat in org.refcodes.time
Methods in org.refcodes.time that return DateFormatModifier and TypeMethodDescriptionstatic DateFormatReturns the enum constant of this type with the specified name.static DateFormat[]DateFormat.values()Returns an array containing the constants of this enum type, in the order they are declared.