Uses of Class
org.refcodes.time.TimeUnit
-
-
Uses of TimeUnit in org.refcodes.time
Methods in org.refcodes.time that return TimeUnit Modifier and Type Method Description static TimeUnitTimeUnit. valueOf(String name)Returns the enum constant of this type with the specified name.static TimeUnit[]TimeUnit. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.time with parameters of type TimeUnit Modifier and Type Method Description floatTimeAccessor. getTime(TimeUnit aTimeUnit)Retrieves the time from the time property.default floatTimeAccessor.TimeProperty. letTime(float aTime, TimeUnit aTimeUnit)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given time (setter) as ofTimeAccessor.TimeMutator.setTime(float, TimeUnit)and returns the very same value (getter).voidTimeAccessor.TimeMutator. setTime(float aTime, TimeUnit aTimeUnit)Sets the time for the time property.static longTimeUnit. toMilliseconds(TimeUnit aTimeUnit, long aTime)Converts a given time from the providedTimeUnitto milliseconds.floatTimeUnit. toTime(TimeUnit aFromTimeUnit, long aFromTime)Converts a given time from oneTimeUnitto this instance's time unit.static floatTimeUnit. toTimeUnit(TimeUnit aFromTimeUnit, long aTime, TimeUnit aToTimeUnit)BTimeAccessor.TimeBuilder. withTime(float aTime, TimeUnit aTimeUnit)Sets the time for the time property.
-