-
Methods in org.refcodes.time that return TimeUnit
| Modifier and Type |
Method |
Description |
static TimeUnit |
TimeUnit.valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static TimeUnit[] |
TimeUnit.values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
Methods in org.refcodes.time with parameters of type TimeUnit
| Modifier and Type |
Method |
Description |
float |
TimeAccessor.getTime(TimeUnit aTimeUnit) |
Retrieves the time from the time property.
|
default float |
TimeAccessor.TimeProperty.letTime(float aTime,
TimeUnit aTimeUnit) |
|
void |
TimeAccessor.TimeMutator.setTime(float aTime,
TimeUnit aTimeUnit) |
Sets the time for the time property.
|
static long |
TimeUnit.toMilliseconds(TimeUnit aTimeUnit,
long aTime) |
Converts a given time from the provided TimeUnit to milliseconds.
|
float |
TimeUnit.toTime(TimeUnit aFromTimeUnit,
long aFromTime) |
Converts a given time from one TimeUnit to this instance's time
unit.
|
static float |
TimeUnit.toTimeUnit(TimeUnit aFromTimeUnit,
long aTime,
TimeUnit aToTimeUnit) |
|
B |
TimeAccessor.TimeBuilder.withTime(float aTime,
TimeUnit aTimeUnit) |
Sets the time for the time property.
|